@@ -2,9 +2,12 @@
 
 from .util import _props_to_component, _extract_props, _extract_fieldrefs, \
     _parse_string_enum, _underlower, _range_to_gridrange_object
+
+import re
                   
 class FormattingComponent(object):
     _FIELDS = ()
+    _DEFAULTS = {}
 
     @classmethod
     def from_props(cls, props):
@@ -27,15 +30,21 @@ class FormattingComponent(object):
     def to_props(self):
         p = {}
         for a in self._FIELDS:
-            if getattr(self, a) is not None:
-                p[a] = _extract_props(getattr(self, a))
+            v = getattr(self, a, None)
+            if v is None:
+                v = self._DEFAULTS.get(a)
+            if v is not None:
+                p[a] = _extract_props(v)
         return p
 
     def affected_fields(self, prefix):
         fields = []
         for a in self._FIELDS:
-            if getattr(self, a) is not None:
-                fields.extend( _extract_fieldrefs(a, getattr(self, a), prefix) )
+            v = getattr(self, a, None)
+            if v is None:
+                v = self._DEFAULTS.get(a)
+            if v is not None:
+                fields.extend( _extract_fieldrefs(a, v, prefix) )
         return fields
 
     def __eq__(self, other):
@@ -43,7 +52,11 @@ class FormattingComponent(object):
             return False
         for a in self._FIELDS:
             self_v = getattr(self, a, None)
+            if self_v == None:
+                self_v = self._DEFAULTS.get(a)
             other_v = getattr(other, a, None)
+            if other_v == None:
+                other_v = other._DEFAULTS.get(a)
             if self_v != other_v:
                 return False
         return True
@@ -168,10 +181,8 @@ class NumberFormat(CellFormatComponent):
 
     TYPES = set(['TEXT', 'NUMBER', 'PERCENT', 'CURRENCY', 'DATE', 'TIME', 'DATE_TIME', 'SCIENTIFIC'])
 
-    def __init__(self, type, pattern=None):
-        if type.upper() not in NumberFormat.TYPES:
-            raise ValueError("NumberFormat.type must be one of: %s" % NumberFormat.TYPES)
-        self.type = type.upper()
+    def __init__(self, type=None, pattern=None):
+        self.type = _parse_string_enum('type', type, NumberFormat.TYPES, True)
         self.pattern = pattern
 
 class ColorStyle(CellFormatComponent):
@@ -185,7 +196,14 @@ class ColorStyle(CellFormatComponent):
         self.rgbColor = rgbColor
 
 class Color(CellFormatComponent):
+    _HEX_PATTERN = re.compile(r'^#([0-9a-f]{2})([0-9a-f]{2})([0-9a-f]{2})([0-9a-f]{2})?$', re.IGNORECASE)
     _FIELDS = ('red', 'green', 'blue', 'alpha')
+    _DEFAULTS = {
+        'red': 0.0,
+        'green': 0.0,
+        'blue': 0.0,
+        'alpha': 1.0
+    }
 
     def __init__(self, red=None, green=None, blue=None, alpha=None):
         self.red = red
@@ -195,51 +213,26 @@ class Color(CellFormatComponent):
 
     @classmethod
     def fromHex(cls,hexcolor):
-        # Check Hex String
-        if not hexcolor.startswith('#'):
-            raise ValueError('Color string given: %s: Hex color strings must start with #' % hexcolor)
-        hexlen = len(hexcolor)
-        if hexlen != 7 and hexlen != 9:
-            raise ValueError('Color string given: %s: Hex string must be of the form: "#RRGGBB" or "#RRGGBBAA' % hexcolor)
-        # Remainder of string should be parsable as hex
-        try:
-            if int(hexcolor[1:],16):
-                pass
-        except Exception as e:
-            raise ValueError('Color string given: %s: Bad color string entered' % hexcolor)
-        # Convert Hex range 0-255 to 0-1.0
-        RR = int(hexcolor[1:3],16) / 255.0
-        GG = int(hexcolor[3:5],16) / 255.0
-        BB = int(hexcolor[5:7],16) / 255.0
-        # Slices wont causes IndexErrors
-        A = hexcolor[7:9]
-        if not A:
-            AA = None
-        else:
-            AA = int(A,16) / 255.0
-        return cls(red=RR,green=GG,blue=BB,alpha=AA)
+        match = cls._HEX_PATTERN.search(hexcolor)
+        if not match:
+            raise ValueError('Color string given: %s: Hex string must be of the form: "#RRGGBB" or "#RRGGBBAA"' % hexcolor)
+        # Convert Hex range 0-255 to 0-1.0 for red, green, blue, alpha
+        return cls(*[int(a, 16)/255.0 if a else None for a in match.groups()])
 
     def toHex(self):
         RR = format(int((self.red if self.red else 0) * 255), '02x')
         GG = format(int((self.green if self.green else 0) * 255), '02x')
         BB = format(int((self.blue if self.blue else 0) * 255), '02x')
         AA = format(int((self.alpha if self.alpha else 0) * 255), '02x')
-
-        if self.alpha != None:
-            hexformat = '#{RR}{GG}{BB}{AA}'.format(RR=RR,GG=GG,BB=BB,AA=AA)
-        else:
-            hexformat = '#{RR}{GG}{BB}'.format(RR=RR,GG=GG,BB=BB)
-        return hexformat
+        return '#{0}{1}{2}{3}'.format(RR, GG, BB, (AA if self.alpha != None else ''))
 
 class Border(CellFormatComponent):
     _FIELDS = ('style', 'color', 'colorStyle')
 
     STYLES = set(['DOTTED', 'DASHED', 'SOLID', 'SOLID_MEDIUM', 'SOLID_THICK', 'NONE', 'DOUBLE'])
 
-    def __init__(self, style, color=None, width=None, colorStyle=None):
-        if style.upper() not in Border.STYLES:
-            raise ValueError("Border.style must be one of: %s" % Border.STYLES)
-        self.style = style.upper()
+    def __init__(self, style=None, color=None, width=None, colorStyle=None):
+        self.style = _parse_string_enum('style', style, Border.STYLES, True)
         self.width = width
         self.color = color
         self.colorStyle = colorStyle
