@@ -135,6 +135,7 @@ class RangeConversionTest(unittest.TestCase):
             self.assertTrue(isinstance(exc, ValueError))
 
 class GspreadTest(unittest.TestCase):
+    maxDiff = None
     config = None
     gc = None
 
@@ -256,8 +257,8 @@ class WorksheetTest(GspreadTest):
         orig_fmt = get_user_entered_format(self.sheet, 'A1')
         new_fmt = cellFormat(borders=borders(bottom=border('SOLID')), padding=padding(bottom=3))
         format_cell_range(self.sheet, 'A1:A1', new_fmt)
+        # Sheets API bug: user entered format will now contain default color and colorStyle.rgbColor
         ue_fmt = get_user_entered_format(self.sheet, 'A1')
-        self.assertEqual(ue_fmt, fmt + new_fmt)
         self.assertEqual(new_fmt.borders.bottom.style, ue_fmt.borders.bottom.style)
         self.assertEqual(new_fmt.padding.bottom, ue_fmt.padding.bottom)
         eff_fmt = get_effective_format(self.sheet, 'A1')
@@ -317,6 +318,35 @@ class WorksheetTest(GspreadTest):
         dt = self.sheet.acell('A1').value
         self.assertEqual(dt, ' 01 09 2018')
 
+    def test_blank_color_as_black(self):
+        rows = [
+            ["A", "B", "C", "D"],
+            ["1", "2", "3", "4"],
+            ["A", "B", "C", "D"],
+            ["TRUE", "FALSE", "FALSE", "TRUE"],
+        ]
+        cell_list = self.sheet.range('A1:D4')
+        for cell, value in zip(cell_list, itertools.chain(*rows)):
+            cell.value = value
+        self.sheet.update_cells(cell_list, value_input_option='USER_ENTERED')
+        fmt = CellFormat(backgroundColor=Color(0,0,0,1))
+        format_cell_range(self.sheet, '1:1', fmt)
+        ue_fmt = get_user_entered_format(self.sheet, 'A1')
+        self.assertEqual(ue_fmt.backgroundColor, Color(0,0,0,1))
+        self.assertEqual(ue_fmt.backgroundColor, Color())
+        fmt = CellFormat(backgroundColor=Color(red=1))
+        format_cell_range(self.sheet, '1:1', fmt)
+        ue_fmt = get_user_entered_format(self.sheet, 'A1')
+        self.assertEqual(ue_fmt.backgroundColor, Color(1,0,0,1))
+        self.assertEqual(ue_fmt.backgroundColor, Color(red=1))
+        fmt = CellFormat(backgroundColor=Color())
+        format_cell_range(self.sheet, '1:1', fmt)
+        ue_fmt = get_user_entered_format(self.sheet, 'A1')
+        eff_fmt = get_effective_format(self.sheet, 'A1')
+        self.assertEqual(ue_fmt.backgroundColor, Color(0,0,0,1))
+        self.assertEqual(ue_fmt.backgroundColor, Color())
+
+
     def test_data_validation_rule(self):
         rows = [
             ["A", "B", "C", "D"],
@@ -396,14 +426,27 @@ class WorksheetTest(GspreadTest):
         # re-saving _always_ sends a request to API, even if no local changes made
         self.assertNotEqual(current_rules.save(), None)
         current_rules = get_conditional_format_rules(self.sheet)
-        self.assertEqual(list(current_rules), [new_rule, new_rule_2])
+        self.assertEqual(
+            current_rules.rules[0].booleanRule.format.textFormat.bold, 
+            new_rule.booleanRule.format.textFormat.bold
+        )
+        self.assertEqual(
+            current_rules.rules[1].gradientRule.maxpoint.colorStyle.themeColor, 
+            new_rule_2.gradientRule.maxpoint.colorStyle.themeColor, 
+        )
         current_rules[0] = new_rule_2
         del current_rules[1]
         current_rules.append(new_rule)
-        self.assertEqual(list(current_rules), [new_rule_2, new_rule])
         self.assertNotEqual(current_rules.save(), None)
         current_rules = get_conditional_format_rules(self.sheet)
-        self.assertEqual(list(current_rules), [new_rule_2, new_rule])
+        self.assertEqual(
+            current_rules.rules[1].booleanRule.format.textFormat.bold, 
+            new_rule.booleanRule.format.textFormat.bold
+        )
+        self.assertEqual(
+            current_rules.rules[0].gradientRule.maxpoint.colorStyle.themeColor, 
+            new_rule_2.gradientRule.maxpoint.colorStyle.themeColor, 
+        )
 
         bold_fmt = get_effective_format(self.sheet, 'A1')
         normal_fmt = get_effective_format(self.sheet, 'C1')
@@ -416,6 +459,55 @@ class WorksheetTest(GspreadTest):
         current_rules = get_conditional_format_rules(self.sheet)
         self.assertEqual(list(current_rules), [])
 
+    def test_conditionals_issue_31(self):
+        rules = [
+            ConditionalFormatRule(
+                ranges=[GridRange(self.sheet.id, 1, 1, 1, 2)],
+                booleanRule=BooleanRule(
+                    BooleanCondition('NUMBER_EQ', ['1']),
+                    CellFormat(textFormat=TextFormat(foregroundColor=Color.fromHex("#000000")))
+                )
+            ),
+            ConditionalFormatRule(
+                ranges=[GridRange(self.sheet.id, 2, 3, 2, 3)],
+                booleanRule=BooleanRule(
+                    BooleanCondition('NUMBER_EQ', ['1']),
+                    CellFormat(textFormat=TextFormat(foregroundColor=Color.fromHex("#00FFFF")))
+                )
+           ),
+            ConditionalFormatRule(
+                ranges=[GridRange(self.sheet.id, 1, 2, 1, 3)],
+                booleanRule=BooleanRule(
+                    BooleanCondition('NUMBER_EQ', ['1']),
+                    CellFormat(textFormat=TextFormat(foregroundColor=Color.fromHex("#FFFF00")))
+                )
+            )
+        ]
+        rows = [
+            ["A", "B", "C", "D"],
+            ["1", "2", "3", "4"]
+        ]
+        cell_list = self.sheet.range('A1:D2')
+        for cell, value in zip(cell_list, itertools.chain(*rows)):
+            cell.value = value
+        current_rules = get_conditional_format_rules(self.sheet)
+        current_rules.extend(rules)
+        self.assertNotEqual(current_rules.save(), None)
+        current_rules_fetched = get_conditional_format_rules(self.sheet)
+        self.assertEqual(
+            current_rules_fetched.rules[0].booleanRule.format.textFormat.foregroundColor,
+            current_rules.rules[0].booleanRule.format.textFormat.foregroundColor
+        )
+        self.assertEqual(
+            current_rules_fetched.rules[1].booleanRule.format.textFormat.foregroundColor,
+            current_rules.rules[1].booleanRule.format.textFormat.foregroundColor
+        )
+        self.assertEqual(
+            current_rules_fetched.rules[2].booleanRule.format.textFormat.foregroundColor,
+            current_rules.rules[2].booleanRule.format.textFormat.foregroundColor
+        )
+
+
     def test_dataframe_formatter(self):
         rows = [  
             {
@@ -598,3 +690,10 @@ class FormattingComponentTest(unittest.TestCase):
             TextRotation(angle=1, vertical=True)
         with self.assertRaises(ValueError):
             TextRotation()
+
+class GridRangeTest(unittest.TestCase):
+
+    def test_absent_sheet_id(self):
+        gr = GridRange.from_props({'startRowIndex': 1})
+        self.assertEqual(0, gr.sheetId)
+        self.assertEqual(1, gr.startRowIndex)
